@@ -155,6 +155,10 @@ template<> struct is_error_condition_enum<errc::errc_t>
 };
 
 // class error_category
+#if ( defined( BOOST_GCC ) && BOOST_GCC >= 40600 ) || defined( BOOST_CLANG )
+#pragma GCC diagnostic push
+  //#pragma GCC diagnostic ignored "-Wnon-virtual-dtor"
+#endif
 
 #ifdef BOOST_MSVC
 #pragma warning( push )
@@ -314,6 +318,10 @@ public:
 
 } // namespace detail
 
+#if ( defined( BOOST_GCC ) && BOOST_GCC >= 40600 ) || defined( BOOST_CLANG )
+#pragma GCC diagnostic pop
+#endif
+
 // generic_category(), system_category()
 
 #if defined(BOOST_SYSTEM_HAS_CONSTEXPR)
@@ -321,14 +329,17 @@ public:
 namespace detail
 {
 
-template<class T> struct cat_holder
+template<class T> struct BOOST_SYMBOL_VISIBLE cat_holder
 {
-    BOOST_SYSTEM_REQUIRE_CONST_INIT static constexpr system_error_category system_category_instance{};
-    BOOST_SYSTEM_REQUIRE_CONST_INIT static constexpr generic_error_category generic_category_instance{};
+    static constexpr system_error_category system_category_instance{};
+    static constexpr generic_error_category generic_category_instance{};
 };
 
-template<class T> BOOST_SYSTEM_REQUIRE_CONST_INIT constexpr system_error_category cat_holder<T>::system_category_instance;
-template<class T> BOOST_SYSTEM_REQUIRE_CONST_INIT constexpr generic_error_category cat_holder<T>::generic_category_instance;
+// Before C++17 it was mandatory to redeclare all static constexpr
+#if defined(BOOST_NO_CXX17_INLINE_VARIABLES)
+template<class T> constexpr system_error_category cat_holder<T>::system_category_instance;
+template<class T> constexpr generic_error_category cat_holder<T>::generic_category_instance;
+#endif
 
 } // namespace detail
 
@@ -344,12 +355,16 @@ constexpr error_category const & generic_category() BOOST_NOEXCEPT
 
 #else // #if defined(BOOST_SYSTEM_HAS_CONSTEXPR)
 
+inline error_category const & system_category() BOOST_NOEXCEPT BOOST_SYMBOL_VISIBLE;
+
 inline error_category const & system_category() BOOST_NOEXCEPT
 {
     static const detail::system_error_category system_category_instance;
     return system_category_instance;
 }
 
+inline error_category const & generic_category() BOOST_NOEXCEPT BOOST_SYMBOL_VISIBLE;
+
 inline error_category const & generic_category() BOOST_NOEXCEPT
 {
     static const detail::generic_error_category generic_category_instance;
@@ -499,7 +514,7 @@ public:
 
     BOOST_SYSTEM_CONSTEXPR explicit operator bool() const BOOST_NOEXCEPT  // true if error
     {
-        return failed_;
+        return val_ != 0;
     }
 
 #else
@@ -509,12 +524,12 @@ public:
 
     BOOST_SYSTEM_CONSTEXPR operator unspecified_bool_type() const BOOST_NOEXCEPT  // true if error
     {
-        return failed_? unspecified_bool_true: 0;
+        return val_ != 0? unspecified_bool_true: 0;
     }
 
     BOOST_SYSTEM_CONSTEXPR bool operator!() const BOOST_NOEXCEPT  // true if no error
     {
-        return !failed_;
+        return val_ == 0;
     }
 
 #endif
@@ -640,7 +655,7 @@ public:
 
     BOOST_SYSTEM_CONSTEXPR explicit operator bool() const BOOST_NOEXCEPT  // true if error
     {
-        return failed_;
+        return val_ != 0;
     }
 
 #else
@@ -650,12 +665,12 @@ public:
 
     BOOST_SYSTEM_CONSTEXPR operator unspecified_bool_type() const  BOOST_NOEXCEPT // true if error
     {
-        return failed_? unspecified_bool_true: 0;
+        return val_ != 0? unspecified_bool_true: 0;
     }
 
     BOOST_SYSTEM_CONSTEXPR bool operator!() const BOOST_NOEXCEPT // true if no error
     {
-        return !failed_;
+        return val_ == 0;
     }
 
 #endif
@@ -772,7 +787,7 @@ inline std::size_t hash_value( error_code const & ec )
 
     if( id == 0 )
     {
-        id = reinterpret_cast<boost::ulong_long_type>( &cat );
+        id = reinterpret_cast<boost::uintptr_t>( &cat );
     }
 
     boost::ulong_long_type hv = ( boost::ulong_long_type( 0xCBF29CE4 ) << 32 ) + 0x84222325;
@@ -852,7 +867,7 @@ inline char const * error_category::message( int ev, char * buffer, std::size_t
 # elif defined(__clang__) && defined(__has_warning)
 #  pragma clang diagnostic push
 #  if __has_warning("-Wdeprecated-declarations")
-//#   pragma clang diagnostic ignored "-Wdeprecated-declarations"
+        //#   pragma clang diagnostic ignored "-Wdeprecated-declarations"
 #  endif
 # endif
 
